def slateblue():return 0x6A5ACD
def slateblue1():return 0x836FFF
def slateblue3():return 0x6959CD
def darkslateblue():return 0x483D8B
def midnightblue():return 0x191970
def navy():return 0x000080
def darkblue():return 0x00008B
def mediumblue():return 0x0000CD
def blue():return 0x0000FF
def cornflowerblue():return 0x6495ED
def royalblue():return 0x4169E1
def dodgerblue():return 0x1E90FF
def deepskyblue():return 0x00BFFF
def lightskyblue():return 0x87CEFA
def skyblue():return 0x87CEEB
def lightblue():return 0xADD8E6
def steelblue():return 0x4682B4
def lightsteelblue():return 0xB0C4DE
def slategray():return 0x708090
def lightslategray():return 0x778899