from ..colors.gray import *
from ..colors.blue import *
from ..colors.cyan import *
from ..colors.brown import *
from ..colors.purple import *
from ..colors.pink import *
from ..colors.green import *
from ..colors.red import *
from ..colors.orange import *
from ..colors.yellow import *
from ..colors.ligthcolors import *


def stringColor(cor: str) -> int:
    """
    Using StringColor:

    >>> import hexacolors
    >>> hexacolors.stringColor('Blue')
    >>> print(hexacolors.listall) #List all colors availables
    """

    match cor.lower().replace(' ', ''):

        case 'black': return black()
        case 'gray1': return grey11()
        case 'gray2': return grey21()
        case 'gray3': return grey31()
        case 'dimgray': return dimgray()
        case 'gray': return gray()
        case 'darkgray': return darkgray()
        case 'silver': return silver()
        case 'ligthgrey': return ligthgrey()
        case 'gainsboro': return gainsboro()
        case 'slateblue': return slateblue()
        case 'slateblue1': return slateblue1()
        case 'slateblue2': return slateblue3()
        case 'darkslateblue': return darkslateblue()
        case 'midnightblue': return midnightblue()
        case 'navy': return navy()
        case 'darkblue': return darkblue()
        case 'mediumblue': return mediumblue()
        case 'blue': return blue()
        case 'cornflowerblue': return cornflowerblue()
        case 'royalblue': return royalblue()
        case 'dodgerblue': return dodgerblue()
        case 'deepskyblue': return deepskyblue()
        case 'lightskyblue': return lightskyblue()
        case 'skyblue': return skyblue()
        case 'lightblue': return lightblue()
        case 'steelblue': return steelblue()
        case 'lightsteelblue': return lightsteelblue()
        case 'slategray': return slategray()
        case 'lightslategray': return lightslategray()
        case 'cyan': return cyan()
        case 'darkturquoise': return darkturquoise()
        case 'turquoise': return turquoise()
        case 'mediumturquoise': return mediumturquoise()
        case 'lightseagreen': return lightseagreen()
        case 'darkcyan': return darkcyan()
        case 'teal': return teal()
        case 'aquamarine': return aquamarine()
        case 'mediumaquamarine': return mediumaquamarine()
        case 'cadetblue': return cadetblue()
        case 'darkkhaki': return darkkhaki()
        case 'goldenrod': return goldenrod()
        case 'darkgoldenrod': return darkgoldenrod()
        case 'saddlebrown': return saddlebrown()
        case 'sienna': return sienna()
        case 'rosybrown': return rosybrown()
        case 'peru': return peru()
        case 'chocolate': return chocolate()
        case 'sandybrown': return sandybrown()
        case 'navajowhite': return navajowhite()
        case 'wheat': return wheat()
        case 'burlywood': return burlywood()
        case 'tan': return tan()
        case 'mediumslateBllue': return mediumslateBllue()
        case 'mediumpurple': return mediumpurple()
        case 'blueviolet': return blueviolet()
        case 'indigo': return indigo()
        case 'darkviolet': return darkviolet()
        case 'darkorchid': return darkorchid()
        case 'mediumorchid': return mediumorchid()
        case 'purple': return purple()
        case 'darkmagenta': return darkmagenta()
        case 'magenta': return magenta()
        case 'violet': return violet()
        case 'orchid': return orchid()
        case 'plum': return plum()
        case 'mediumvioletred': return mediumvioletred()
        case 'deeppink': return deeppink()
        case 'hotpink': return hotpink()
        case 'palevioletred': return palevioletred()
        case 'lightpink': return lightpink()
        case 'pink': return pink()
        case 'lightcoral': return lightcoral()
        case 'indianred': return indianred()
        case 'crimson': return crimson()
        case 'darkslategreen': return darkslategreen()
        case 'mediumspringgreen': return mediumspringgreen()
        case 'springgreen': return springgreen()
        case 'palegreen': return palegreen()
        case 'lightgreen': return lightgreen()
        case 'darkseagreen': return darkseagreen()
        case 'mediumseagreen': return mediumseagreen()
        case 'seagreen': return seagreen()
        case 'darkgreen': return darkgreen()
        case 'green': return green()
        case 'forestgreen': return forestgreen()
        case 'limegreen': return limegreen()
        case 'lime': return lime()
        case 'lawngreen': return lawngreen()
        case 'chartreuse': return chartreuse()
        case 'greenyellow': return greenyellow()
        case 'yellowgreen': return yellowgreen()
        case 'olivedrab': return olivedrab()
        case 'darkolivegreen': return darkolivegreen()
        case 'olive': return olive()
        case 'maroon': return maroon()
        case 'darkred': return darkred()
        case 'firebrick': return firebrick()
        case 'brown': return brown()
        case 'salmon': return salmon()
        case 'darksalmon': return darksalmon()
        case 'lightsalmon': return lightsalmon()
        case 'coral': return coral()
        case 'tomato': return tomato()
        case 'red': return red()
        case 'orangered': return orangered()
        case 'darkorange': return darkorange()
        case 'orange': return orange()
        case 'gold': return gold()
        case 'yellow': return yellow()
        case 'khaki': return khaki()
        case 'white': return white()
        case 'aliceblue': return aliceblue()
        case 'ghostwhite': return ghostwhite()
        case 'snow': return snow()
        case 'seashell': return seashell()
        case 'floralwhite': return floralwhite()
        case 'whitesmoke': return whitesmoke()
        case 'beige': return beige()
        case 'oldlace': return oldlace()
        case 'ivory': return ivory()
        case 'linen': return linen()
        case 'cornsilk': return cornsilk()
        case 'antiquewhite': return antiquewhite()
        case 'blanchedalmond': return blanchedalmond()
        case 'bisque': return bisque()
        case 'lightyellow': return lightyellow()
        case 'lemonchiffon': return lemonchiffon()
        case 'lightgoldenrodyellow': return lightgoldenrodyellow()
        case 'papayawhip': return papayawhip()
        case 'peachpuff': return peachpuff()
        case 'moccasin': return moccasin()
        case 'palegoldenrod': return palegoldenrod()
        case 'mistyrose': return mistyrose()
        case 'lavenderblush': return lavenderblush()
        case 'lavender': return lavender()
        case 'thistle': return thistle()
        case 'azure': return azure()
        case 'lightcyan': return lightcyan()
        case 'powderblue': return powderblue()
        case 'paleturquoise': return paleturquoise()
        case 'honeydew': return honeydew()
        case 'mintcream': return mintcream()
