def darkslategreen():return 0x2F4F4F
def mediumspringgreen():return 0x00FA9A
def springgreen():return 0x00FF7F
def palegreen():return 0x98FB98
def lightgreen():return 0x90EE90
def darkseagreen():return 0x8FBC8F
def mediumseagreen():return 0x3CB371
def seagreen():return 0x2E8B57
def darkgreen():return 0x006400
def green():return 0x008000
def forestgreen():return 0x228B22
def limegreen():return 0x32CD32
def lime():return 0x00FF00
def lawngreen():return 0x7CFC00
def chartreuse():return 0x7FFF00
def greenyellow():return 0xADFF2F
def yellowgreen():return 0x9ACD32
def olivedrab():return 0x6B8E23
def darkolivegreen():return 0x556B2F
def olive():return 0x808000