def white():return 0xFFFFFF
def aliceblue():return 0xF0F8FF
def ghostwhite():return 0xF8F8FF
def snow():return 0xFFFAFA
def seashell():return 0xFFF5EE
def floralwhite():return 0xFFFAF0
def whitesmoke():return 0xF5F5F5
def beige():return 0xF5F5DC
def oldlace():return 0xFDF5E6
def ivory():return 0xFFFFF0
def linen():return 0xFAF0E6
def cornsilk():return 0xFFF8DC
def antiquewhite():return 0xFAEBD7
def blanchedalmond():return 0xFFEBCD
def bisque():return 0xFFE4C4
def lightyellow():return 0xFFFFE0
def lemonchiffon():return 0xFFFACD
def lightgoldenrodyellow():return 0xFAFAD2
def papayawhip():return 0xFFEFD5
def peachpuff():return 0xFFDAB9
def moccasin():return 0xFFE4B5
def palegoldenrod():return 0xEEE8AA
def mistyrose():return 0xFFE4E1
def lavenderblush():return 0xFFF0F5
def lavender():return 0xE6E6FA
def thistle():return 0xD8BFD8
def azure():return 0xF0FFFF
def lightcyan():return 0xE0FFFF
def powderblue():return 0xB0E0E6
def paleturquoise():return 0xE0FFFF
def honeydew():return 0xF0FFF0
def mintcream():return 0xF5FFFA